<?php
/**
 * CMB2 Theme Options
 * @version 0.1.0
 */
class Car_Pages_Admin {

	/**
 	 * Option key, and option page slug
 	 * @var string
 	 */
	private $key = 'car_sales_pages_options';

	/**
 	 * Options page metabox id
 	 * @var string
 	 */
	private $metabox_id = 'car_sales_pages_option_metabox';

	/**
	 * Array of metaboxes/fields
	 * @var array
	 */
	protected $option_metabox = array();

	/**
	 * Options Page title
	 * @var string
	 */
	protected $title = '';

	/**
	 * Options Page hook
	 * @var string
	 */
	protected $options_page = '';

	/**
	 * Constructor
	 * @since 0.1.0
	 */

	protected $menu_names = array();



	public function __construct() {
		// Set our title
		$this->title = __( 'Car Options', 'car-sales-pages' );
	}

	/**
	 * Initiate our hooks
	 * @since 0.1.0
	 */
	public function hooks() {
		add_action( 'init', array( $this, 'wordpress_menu_names' ) );
		add_action( 'admin_init', array( $this, 'init' ) );
		add_action( 'admin_menu', array( $this, 'add_options_page' ) );
		add_action( 'cmb2_init', array( $this, 'add_options_page_metabox' ) );
	}


	/**
	 * Register our setting to WP
	 * @since  0.1.0
	 */
	public function init() {
		register_setting( $this->key, $this->key );
	}

	/**
	 * Add menu options page
	 * @since 0.1.0
	 */
	public function add_options_page() {
		$this->options_page = add_menu_page( $this->title, $this->title, 'manage_options',$this->key, array( $this, 'admin_page_display' ) );


	}

	/**
	 * Admin page markup. Mostly handled by CMB2
	 * @since  0.1.0
	 */
	public function admin_page_display() {
		?>
		<div class="wrap cmb2_options_page <?php echo $this->key; ?>">
			<h2><?php echo esc_html( get_admin_page_title() ); ?></h2>
			<?php cmb2_metabox_form( $this->metabox_id, $this->key ); ?>
		</div>
		<?php
	}

	/**
	 * Add the options metabox to the array of metaboxes
	 * @since  0.1.0
	 * @param  array $meta_boxes
	 * @return array $meta_boxes
	 */
	function add_options_page_metabox() {

		$cmb = new_cmb2_box( array(
			'id'      => $this->metabox_id,
			'hookup'  => false,
			'show_on' => array(
				// These are important, don't remove
				'key'   => 'options-page',
				'value' => array( $this->key, )
			),
		) );

		// Set our CMB2 fields




		$cmb->add_field( array(
	    'name'             => __( 'Select a Menu', 'car-sales-pages' ),
	    'desc'             => __( 'This will appear at the top of each car sales page', 'car-sales-pages' ),
	    'id'               => 'settings_menu',
	    'type'             => 'select',
	    'show_option_none' => false,
	    'default'          => '',
    	'options'          => $this->menu_names
		) );



		$cmb->add_field( array(
			'name'    => __( 'Menu Background Color', 'car-sales-pages' ),
			'desc'    => __( 'Car menu background color', 'car-sales-pages' ),
			'id'      => 'settings_colorpicker',
			'type'    => 'colorpicker',
			'default' => '#f7f7f7',
		) );

		$cmb->add_field( array(
		    'name' => ' ',
		    'desc' => '<a target="_blank" href="http://www.thinklandingpages.com/car-sales-page/" class="quick-start-guide">Get the car sales page quick start guide</a>',
		    'type' => 'title',
		    'id'   => 'wiki_test_title'
		) );



		
	}


	/**
	 * Defines the theme option metabox and field configuration
	 * @since  0.1.0
	 * @return array
	 */
	public function option_metabox() {
		return ;
	}

	/**
	 * Public getter method for retrieving protected/private variables
	 * @since  0.1.0
	 * @param  string  $field Field to retrieve
	 * @return mixed          Field value or exception is thrown
	 */
	public function __get( $field ) {
		// Allowed fields to retrieve
		if ( in_array( $field, array( 'key', 'metabox_id', 'fields', 'title', 'options_page' ), true ) ) {
			return $this->{$field};
		}

		throw new Exception( 'Invalid property: ' . $field );
	}


	/**
	 * create an array of wordpress menu names
	 * @since  0.1.0
	 */
	public function wordpress_menu_names() {
		

		$nav_menus = wp_get_nav_menus();

		$this->menu_names[''] = __( 'none', 'car-sales-pages' );

		foreach ($nav_menus as $nav_menu) {

			$this->menu_names[$nav_menu->name] = __( $nav_menu->name, 'car-sales-pages' );
			  
		}

	}


}

// Get it started
$GLOBALS['car_sales_pages_admin'] = new Car_Pages_Admin();
$GLOBALS['car_sales_pages_admin']->hooks();

/**
 * Helper function to get/return the car_sales_pages_Admin object
 * @since  0.1.0
 * @return car_sales_pages_Admin object
 */
function car_sales_pages_admin() {
	global $car_sales_pages_admin;
	return $car_sales_pages_admin;
}

/**
 * Wrapper function around cmb2_get_option
 * @since  0.1.0
 * @param  string  $key Options array key
 * @return mixed        Option value
 */
function car_sales_pages_get_option( $key = '' ) {
	global $car_sales_pages_admin;
	return cmb2_get_option( $car_sales_pages_admin->key, $key );
	
}







